---
name: Feature/enhancement request
about: Suggest an idea for this project
title: 'Feature/Enhancement Request: '
labels: enhancement
assignees: k98kurz

---

## Feature or Enhancement?

<!-- Choose one by placing an x in the box -->

- ( ) New feature
- ( ) Enhancement of existing feature

## Description

<!-- A clear and concise description of what you want to happen. -->

## Additional context

<!-- Add any other context or screenshots about the feature request here. -->

